%define _disable_ld_no_undefined 1

%define shortname indi
%define srcname   %{shortname}


Summary: Library to control astronomical devices
Name:    indilib
Version: 1.3.1
Release: %mkrel 1
License: LGPLv2+
Group:   Development/C
Url:     http://indi.sourceforge.net/
Source0: https://sourceforge.net/projects/indi/files/%{srcname}-%{version}.tar.gz

Patch0:  indi-1.3.1-paths.patch

BuildRequires: curl-devel
BuildRequires: zlib-devel
BuildRequires: pkgconfig(libusb)
BuildRequires: cfitsio-devel >= 3.090
BuildRequires: libfli-devel
BuildRequires: libnova-devel
BuildRequires: libjpeg-devel
BuildRequires: libgsl-devel
BuildRequires: cmake

Provides: indi = %version-%release

%description
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

%files
%doc libindi/ChangeLog libindi/NEWS libindi/README
%_bindir/*
%_datadir/%{shortname}/
%_libdir/%{shortname}/
%{_udevrulesdir}/99-*.rules

#--------------------------------------------------------------------

%define major 1
%define libname %mklibname %{shortname} %major

%package -n %libname
Summary: Library files for INDI
Group: Development/C

%description -n %libname
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains library files of indilib.

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

#--------------------------------------------------------------------

%define develname %mklibname -d %{shortname}

%package -n %develname
Summary: INDI development files
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: indi-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description -n %develname
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains files needed to build applications using indilib.

%files -n %develname
%doc libindi/ChangeLog libindi/README libindi/NEWS
%_libdir/*.so
%_libdir/pkgconfig/libindi.pc
%_includedir/libindi/

#--------------------------------------------------------------------
# (lm) libindiclient is built as static only
# libindiclient BR by kstars

%define staticname %mklibname -s -d indiclient

%package -n %staticname
Summary: INDI indiclient static development file
Group: Development/C
Requires: %{develname} = %{version}-%{release}
Provides: indiclient-static-devel = %{version}-%release
Conflicts:%{develname} < 0.9.8.1

%description -n %staticname
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains libindiclient static file needed to build applications
using indiclient.

%files -n %staticname
%_libdir/libindiclient.a

#--------------------------------------------------------------------

%prep
%setup -q -n %{srcname}-%{version}
%autopatch -p1

%build
pushd libindi
%cmake  \
	-DUDEVRULES_INSTALL_DIR=%{_udevrulesdir}
%make
popd

%install
pushd libindi
%make_install -C build
popd

find %{buildroot} \( -name "*.a" ! -name "libindiclient.a" \) -delete


%changelog
* Tue Nov 22 2016 eatdirt <eatdirt> 1.3.1-1.mga6
+ Revision: 1068757
- Upgrade indilib to 1.3.1

* Wed Mar 09 2016 eatdirt <eatdirt> 1.2.0-1.mga6
+ Revision: 988569
- Upgrade to version 1.2.0

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.9.8.1-6.mga6
+ Revision: 919006
- rebuild for gsl

* Wed Oct 15 2014 umeabot <umeabot> 0.9.8.1-5.mga5
+ Revision: 739055
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.8.1-4.mga5
+ Revision: 680506
- Mageia 5 Mass Rebuild

* Mon Jul 14 2014 lmenut <lmenut> 0.9.8.1-3.mga5
+ Revision: 651829
- restore libindiclient static only library in indiclient-static-devel

* Sat Jul 05 2014 pterjan <pterjan> 0.9.8.1-2.mga5
+ Revision: 643689
- Replace libusb*-devel BuildRequires by better ones

* Wed Jul 02 2014 wally <wally> 0.9.8.1-1.mga5
+ Revision: 642379
- new version 0.8.9.1
- drop static libs

* Thu Feb 27 2014 eatdirt <eatdirt> 0.9.6-7.mga5
+ Revision: 597698
- Rebuild for new cfitsio

* Sat Oct 19 2013 umeabot <umeabot> 0.9.6-6.mga4
+ Revision: 530063
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 eatdirt <eatdirt> 0.9.6-5.mga4
+ Revision: 454939
- Rebuild for cfitsio 3.350

  + fwang <fwang>
    - there is no boost req

* Wed Jul 10 2013 fwang <fwang> 0.9.6-4.mga4
+ Revision: 452327
- rebuild for new boost

* Wed Jan 16 2013 fwang <fwang> 0.9.6-3.mga3
+ Revision: 388523
- correct udev rules dir

* Sat Jan 12 2013 umeabot <umeabot> 0.9.6-2.mga3
+ Revision: 354397
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 22 2012 mikala <mikala> 0.9.6-1.mga3
+ Revision: 320435
- Update tarball to 0.9.6
- Build with no_undefined
- Minor clean spec

* Sun Sep 02 2012 fedya <fedya> 0.9.5-1.mga3
+ Revision: 287429
- version update 0.9.5

* Fri Jun 08 2012 fwang <fwang> 0.9.1-1.mga3
+ Revision: 257506
- new version 0.9.1
- drop merged pathes

* Sat Jan 14 2012 fwang <fwang> 0.9-1.mga2
+ Revision: 195892
- new version 0.9

* Mon Jun 27 2011 dmorgan <dmorgan> 0.8-1.mga2
+ Revision: 114962
- add boost-devel as buildrequires
- New version 0.8
  Rediff P1
  Fix package layout

* Sat Jan 22 2011 ahmad <ahmad> 0.6.2-1.mga1
+ Revision: 33224
- imported package indilib

